#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_NOT_GREATER_EQUAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_NOT_GREATER_EQUAL_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/scalar/is_not_greater_equal.hpp>

#endif
